@@ -10,7 +10,7 @@ async def create_files(files: list[bytes] = File(...)):
 
 
 @app.post("/uploadfiles/")
-async def create_upload_files(files: list[UploadFile] = File(...)):
+async def create_upload_files(files: list[UploadFile]):
     return {"filenames": [file.filename for file in files]}
 
 
